CardModel class

This class is used by the CardStackWidget for the CardStackWidget.cardList attribute.

Constructors

CardModel({Key? key, Widget? child, Color backgroundColor = Colors.white, Color shadowColor = Colors.black, Radius radius = Radius.zero, BoxBorder? border, EdgeInsets? padding, EdgeInsets? margin, Gradient? gradient, DecorationImage? imageDecoration, double shadowBlurRadius = 2.0})

Properties

backgroundColor → Color
Color applied to the background
final
border → BoxBorder?
Border applied to the child's container decoration
final
child → Widget?
Widget rendered into the stack
final
gradient → Gradient?
Gradient applied to the child's container decoration
final
hashCode → int
The hash code for this object.
no setterinherited
imageDecoration → DecorationImage?
Image for decoration applied to the child's container
final
key → Key?
final
margin → EdgeInsets?
Margin applied to the child's container
final
padding → EdgeInsets?
Padding applied to the child's container
final
radius → Radius
Radius applied to the border
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurRadius → double
Radius applied to the shadow decoration
final
shadowColor → Color
Color of the shadow applied to the card decoration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited